@@ -1,11 +1,12 @@
 from ._config import parameter_client_factory
-from .wrapper import Wrapper, make_wrapper
+from .wrapper import Wrapper, make_wrapper, make_wrapper_simple_client
 from .configuration import Default
 
 
 __all__ = [
     'Wrapper',
     'make_wrapper',
+    'make_wrapper_simple_client',
     'Default',
     'parameter_client_factory'
 ]
