@@ -94,7 +94,7 @@ class WrapperMeta(type):
 
 class WrapperClass(metaclass=WrapperMeta):
     def __init__(self, **kwargs):
-        pass
+        self.__dict__ = kwargs['wrappee'].__dict__
 
     def __getattr__(self, item):
         res = getattr(self.__wrappee__, item)
@@ -178,3 +178,42 @@ def _make_wrapper_simple_client_callback(opt):
 
 def make_wrapper_simple_client(instance, **kwargs):
     return make_wrapper_simple(instance, callback=_make_wrapper_simple_client_callback, **kwargs)
+
+
+def _custom_wrapper_wrap_internal(wrappee, **kwargs):
+    if not callable(wrappee):
+        return CustomWrapper(wrappee, **kwargs)
+    return wrappee
+
+
+class CustomWrapper(wrapt.ObjectProxy):
+    def __init__(self, wrappee, **kwargs):
+        super(CustomWrapper, self).__init__(wrappee)
+        self._self_callback = lambda _: None
+        if 'callback' in kwargs:
+            self._self_callback = kwargs['callback']
+        if 'obj_path' in kwargs:
+            self._self_obj_path = kwargs['obj_path']
+        self._self_obj_type = type(wrappee).__name__
+
+    def __getattr__(self, item):
+        self._self_callback({'event': 'get', 'item': item, 'obj_path': self._self_obj_path, 'obj_type': self._self_obj_type})
+        return _custom_wrapper_wrap_internal(super(CustomWrapper, self).__getattr__(item),
+                                             callback=self._self_callback,
+                                             obj_path='{}.{}'.format(self._self_obj_path, item))
+
+    def __getitem__(self, item):
+        self._self_callback({'event': 'get', 'item': item, 'obj_path': self._self_obj_path, 'obj_type': self._self_obj_type})
+        return _custom_wrapper_wrap_internal(super(CustomWrapper, self).__getitem__(item),
+                                             callback=self._self_callback,
+                                             obj_path='{}[{}]'.format(self._self_obj_path, item))
+
+    def __copy__(self):
+        return _custom_wrapper_wrap_internal(copy.copy(self.__wrappee__))
+
+    def __deepcopy__(self, memodict={}):
+        return _custom_wrapper_wrap_internal(copy.deepcopy(self.__wrappee__, memodict))
+
+
+def make_custom_wrapper_client(wrappee, **kwargs):
+    return _custom_wrapper_wrap_internal(wrappee, **kwargs)
